@@ -40,6 +40,7 @@ static int section_policy_callback(GtkWidget *w, gpointer data);
 static int section_select_callback(GtkWidget *w, gpointer data);
 static int status_bar_callback (GtkWidget *widget, gpointer   data);
 static int search_mode_callback (GtkWidget *widget, gpointer   data);
+static int show_mode_callback(GtkWidget *w, gpointer data);
 static void app_quit(GtkWidget *w, gpointer data);
 static void select_row_callback(GtkWidget *, gint, gint, GdkEventButton *, gpointer);
 static void select_row_callback3(GtkWidget *, gint, gint, GdkEventButton *, gpointer);
@@ -76,13 +77,18 @@ static GtkItemFactoryEntry menu_items[] = {
   {"/Sections/_8: Sys.Administration",NULL,	(void (*)(...))section_select_callback,	1<<7,	"<CheckItem>"},
   {"/Sections/_l: Local",			NULL,	(void (*)(...))section_select_callback,	1<<8,	"<CheckItem>"},
   {"/Sections/_n: New",				NULL,	(void (*)(...))section_select_callback,	1<<9,	"<CheckItem>"},
+  {"/_View",      NULL,         NULL, 0, "<Branch>"},
+  {"/View/x_Term",		"<control>T",	(void (*)(...))show_mode_callback, 0,	"<RadioItem>"},
+  {"/View/_GhostView",		"<control>G",	(void (*)(...))show_mode_callback, 1,	"/View/xTerm"},
+  {"/View/_LocalBrowse",		"<control>L",	(void (*)(...))show_mode_callback, 2,	"/View/xTerm"},
+  {"/View/_NetBrowse",		"<control>N",	(void (*)(...))show_mode_callback, 3,	"/View/xTerm"},
   {"/_Options",      NULL,         NULL, 0, "<Branch>"},
   {"/Options/Status bar",		NULL,	(void (*)(...))status_bar_callback, 0,	"<CheckItem>"},
   {"/Options/sep1",     NULL,         NULL, 0, "<Separator>"},
-  {"/Options/_Index search",    NULL,	(void (*)(...))search_mode_callback, 0, "<RadioItem>"},
-  {"/Options/_Key word search",   NULL, (void (*)(...))search_mode_callback, 1, "/Options/Index search"},
+  {"/Options/_Index search",    "<control>I",	(void (*)(...))search_mode_callback, 0, "<RadioItem>"},
+  {"/Options/_Key word search",   "<control>K", (void (*)(...))search_mode_callback, 1, "/Options/Index search"},
   {"/Options/sep2",     NULL,         NULL, 0, "<Separator>"},
-  {"/Options/Man _Paths...",    "<control>P", 	(void (*)(...))edit_paths_callback, 0, NULL},
+  {"/Options/Man _Paths...",    NULL, 	(void (*)(...))edit_paths_callback, 0, NULL},
   //  {"/Options/Test",  NULL,         (void (*)(...))test_callback, 0, NULL},
   {"/_Help",         NULL,         NULL, 0, "<LastBranch>"},
   {"/_Help/About",   NULL,         GTK_SIGNAL_FUNC(window_help_about_callback),0,NULL}
@@ -99,6 +105,7 @@ GtkTooltips * tooltips;
 GtkWidget * section_buttons[MAX_MAN_SECTION];
 GtkWidget * section_select[3];
 GtkWidget * searching_mode_buttons[2];
+GtkWidget * show_mode_buttons[4];
 GtkWidget * status_bar_button;
 
 int signal_select_row;	//used by select_row_callback() to decide whether to active man pages
@@ -157,6 +164,10 @@ void get_main_menu(GtkWidget *window, GtkWidget ** menubar) {
 	section_buttons[9] = gtk_item_factory_get_widget(item_factory, "/Sections/n: New");
 	searching_mode_buttons[0] = gtk_item_factory_get_widget(item_factory, "/Options/Index search");
 	searching_mode_buttons[1] = gtk_item_factory_get_widget(item_factory, "/Options/Key word search");
+	show_mode_buttons[0] = gtk_item_factory_get_widget(item_factory, "/View/xTerm");
+	show_mode_buttons[1] = gtk_item_factory_get_widget(item_factory, "/View/GhostView");
+	show_mode_buttons[2] = gtk_item_factory_get_widget(item_factory, "/View/LocalBrowse");
+	show_mode_buttons[3] = gtk_item_factory_get_widget(item_factory, "/View/NetBrowse");
 	status_bar_button = gtk_item_factory_get_widget(item_factory, "/Options/Status bar");
 	//  gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(section_buttons[4]),1);
 	updata_menu_buttons(0);
@@ -184,6 +195,12 @@ void updata_menu_buttons(int flag)
 			if(!flag) signal_menu_change++;
 			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(searching_mode_buttons[k]),1);
 		}
+	k = (int)context->get_value("show_mode");
+	if(k>0 && k<=3)
+		if(!(((GtkCheckMenuItem*)(show_mode_buttons[k]))->active)) {
+			if(!flag) signal_menu_change++;
+			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(show_mode_buttons[k]),1);
+		}
 	k2 = (int)context->get_value("show_status_bar");
 	i = k2&(1<<k);
 	j = (((GtkCheckMenuItem*)(status_bar_button))->active);
@@ -435,6 +452,12 @@ static int print_hello(GtkWidget *w, gpointer data) {
 	return 0;
 }
 
+static int print_page(GtkWidget *w, gpointer data) {
+	if(signal_menu_change>0) {signal_menu_change--;return 1;}
+	g_message("Hello, World! %x\n",data);
+	return 0;
+}
+
 static int test_callback(GtkWidget *w, gpointer data) {
 	int i,j;
 	if(signal_menu_change>0) {signal_menu_change--;return 1;}
@@ -554,11 +577,11 @@ static void window_help_about_callback (GtkWidget *widget, gpointer   data)
 		  FALSE, FALSE, 5);
 
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (about_window)->vbox),
-		  gtk_label_new ("Comments and suggestions are extremely welcome!"),
+		  gtk_label_new ("Comments and suggestions are extremely welcomed!"),
 		  FALSE, FALSE, 5);
 
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (about_window)->vbox),
-		  gtk_label_new ("Web: http://homex.s-one.net.sg/user/xkwang/gman"),
+		  gtk_label_new ("Web: http://homex.coolconnect.com/user/xkwang/gman/"),
 		  FALSE, FALSE, 5);
 
 	if (!GTK_WIDGET_VISIBLE (about_window))
@@ -569,7 +592,7 @@ static void window_help_about_callback (GtkWidget *widget, gpointer   data)
 	}
 }
 
-static status_bar_callback (GtkWidget *widget, gpointer   data)
+static int status_bar_callback (GtkWidget *widget, gpointer   data)
 {
 	int k,k2;
 	if(signal_menu_change>0) {signal_menu_change--;return 1;}
@@ -602,6 +625,24 @@ static int search_mode_callback (GtkWidget *widget, gpointer   data)
 	return 0;
 }
 
+static int show_mode_callback (GtkWidget *widget, gpointer   data)
+{
+	int k,k2;
+	k2 = (int) data;
+	if(!((GtkCheckMenuItem*)(show_mode_buttons[k2]))->active) return 1;
+	if(signal_menu_change>0) {signal_menu_change--;return 1;}
+	//if(!signal) {signal++;return 1;}
+	//signal--;
+	k = (int) context->get_value("show_mode");
+	if(k == k2) return 1;
+	pthread_mutex_lock(&context_lock);
+	context->set_value("show_mode","int",(void*)k2);
+	pthread_mutex_unlock(&context_lock);
+	//updata_widget_show(0);
+	//updata_menu_buttons(0);
+	return 0;
+}
+
 static void entry4_activate_callback(GtkWidget *w,gpointer data)
 {
 	keyword = gtk_entry_get_text(GTK_ENTRY(entry4));
